:py:mod:`byma.numy.Numy`
========================

.. py:module:: byma.numy.Numy


Module Contents
---------------

Classes
~~~~~~~

.. autoapisummary::

   byma.numy.Numy.Numy




.. py:class:: Numy


   Defines default options for the numerical methods sub-package


